Module record

Module record 

Implementation of construction and extraction of custom linker section records used to store probe information in an object file.

Functions

process_section
Extract records for all defined probes from our custom linker sections.