Implementation of construction and extraction of custom linker section records used to store probe information in an object file.
Functions
- process_
section - Extract records for all defined probes from our custom linker sections.
Implementation of construction and extraction of custom linker section records used to store probe information in an object file.